about summary refs log tree commit diff
path: root/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'default.nix')
-rw-r--r--default.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/default.nix b/default.nix
index db2c503559..bd2c6012fb 100644
--- a/default.nix
+++ b/default.nix
@@ -65,10 +65,10 @@ let
   # To determine build targets, we walk through the depot tree and
   # fetch attributes that were imported by readTree and are buildable.
   #
   # Any build target that contains `meta.ci = false` will be skipped.
 
   # Is this tree node eligible for build inclusion?
-  eligible = node: (node ? outPath) && (node.meta.ci or true);
+  eligible = node: (node ? outPath) && (!node.meta.ci.skip or true);
 
 in readTree.fix(self: (readDepot {
   depot = self;
@@ -65,10 +65,10 @@ let
   # fetch attributes that were imported by readTree and are buildable.
   #
-  # Any build target that contains `meta.ci = false` will be skipped.
+  # Any build target that contains `meta.ci.skip = true` will be skipped.
 
   # Is this tree node eligible for build inclusion?